/*
 * Copyright (c) 2016, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.consent.logic.impl;

import java.lang.Boolean;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import net.shibboleth.idp.attribute.IdPAttribute;
import jp.gakunin.idp.attribute.UApproveJPIdPAttribute;

import com.google.common.base.Function;

/**
 * Function which returns the optional flag of an attribute,
 */  
public class OptionalAttributeFunction implements Function<IdPAttribute, Boolean> {

    /**
     * Constructor.
     */
    public OptionalAttributeFunction() {}

    /** {@inheritDoc} */
    @Override @Nonnull public Boolean apply(@Nullable final IdPAttribute input) {
        if (input == null) {
            return Boolean.FALSE;
        }

        if (!(input instanceof UApproveJPIdPAttribute)) {
            return Boolean.FALSE;
        }

        return Boolean.valueOf(((UApproveJPIdPAttribute)input).isOptional());
    }

}
