/*
 * Copyright (c) 2016, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.saml.xmlobject.impl;

import javax.annotation.concurrent.ThreadSafe;

import jp.gakunin.idp.saml.xmlobject.RequestedAttributeExtension;
import jp.gakunin.idp.saml.xmlobject.UApproveJPMetadata;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Builder of {@link jp.gakunin.idp.saml.xmlobject.impl.RequestedAttributeExtensionImpl}.
 */
@ThreadSafe
public class RequestedAttributeExtensionBuilder extends AbstractSAMLObjectBuilder<RequestedAttributeExtension> {

    /** Class logger. */
    private final Logger log = LoggerFactory.getLogger(RequestedAttributeExtensionBuilder.class);

    /** {@inheritDoc} */
    public RequestedAttributeExtension buildObject() {
        log.trace("RequestedAttributeExtensionBuilder buildObject.");
        return buildObject(UApproveJPMetadata.NAMESPACE, RequestedAttributeExtension.DEFAULT_ELEMENT_LOCAL_NAME,
                UApproveJPMetadata.PREFIX);
    }

    /** {@inheritDoc} */
    public RequestedAttributeExtension buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        log.trace("RequestedAttributeExtensionBuilder real buildObject.");
        return new RequestedAttributeExtensionImpl(namespaceURI, localName, namespacePrefix);
    }

}
