/*
 * Copyright (c) 2016, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.saml.xmlobject.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.annotation.concurrent.NotThreadSafe;

import jp.gakunin.idp.saml.xmlobject.Description;
import jp.gakunin.idp.saml.xmlobject.RequestedAttributeExtension;

import org.opensaml.saml.common.AbstractSAMLObject;
import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.util.XMLObjectChildrenList;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * Concrete implementation of {@link jp.gakunin.idp.saml.xmlobject.RequestedAttributeExtension}.
 */
@NotThreadSafe
public class RequestedAttributeExtensionImpl extends AbstractSAMLObject implements RequestedAttributeExtension {

    /** Class logger. */
    private final Logger log = LoggerFactory.getLogger(RequestedAttributeExtensionImpl.class);

    /** Description children. */
    private final XMLObjectChildrenList<Description> descriptions;

    /** Human readable name of the attribute. */
    private String friendlyName;

    /**
     * Constructor
     * 
     * @param namespaceURI the namespace the element is in
     * @param elementLocalName the local name of the XML element this Object represents
     * @param namespacePrefix the prefix for the given namespace
     */
    protected RequestedAttributeExtensionImpl(final String namespaceURI, final String elementLocalName,
            final String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
        descriptions = new XMLObjectChildrenList<Description>(this);
    }

    /** {@inheritDoc} */
    @Override
    public String getFriendlyName() {
        log.trace("do getFriendlyName().");
        return friendlyName;
    }

    /** {@inheritDoc} */
    @Override
    public void setFriendlyName(final String friendlyName) {
        log.trace("do setFriendlyName().");
        this.friendlyName = prepareForAssignment(this.friendlyName, friendlyName);
    }

    /** {@inheritDoc} */
    @Override
    public List<Description> getDescriptions() {
        log.trace("do getDescriptions().");
        return descriptions;
    }

    /** {@inheritDoc} */
    @Override
    public List<XMLObject> getOrderedChildren() {
        final ArrayList<XMLObject> children = new ArrayList<XMLObject>();

        log.trace("do getOrderedChildren().");

        children.addAll(getDescriptions());

        return Collections.unmodifiableList(children);
    }

}
